aboutsummaryrefslogtreecommitdiffstats
path: root/src/implementation.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/implementation.h')
-rw-r--r--src/implementation.h8
1 files changed, 6 insertions, 2 deletions
diff --git a/src/implementation.h b/src/implementation.h
index 8c5398c..936322d 100644
--- a/src/implementation.h
+++ b/src/implementation.h
@@ -58,9 +58,13 @@ puglDecodeUTF8(const uint8_t* buf);
void
puglDispatchSimpleEvent(PuglView* view, PuglEventType type);
/// Dispatch `event` to `view` while already in the graphics context
void
-puglDispatchEventInContext(PuglView* view, const PuglEvent* event);
+puglConfigure(PuglView* view, const PuglEvent* event);
+
+/// Process expose event while already in the graphics context
+void
+puglExpose(PuglView* view, const PuglEvent* event);
/// Dispatch `event` to `view`, entering graphics context if necessary
void
@@ -58,9 +58,13 @@ puglDecodeUTF8(const uint8_t* buf);
void
puglDispatchSimpleEvent(PuglView* view, PuglEventType type);
-/// Dispatch `event` to `view` while already in the graphics context
+/// Process configure event while already in the graphics context
void